@@ -1,5 +1,5 @@
 /******************************************************************************
- * mod_uploader / MessageDigest5.cpp
+ * mod_uploader / MessageDigest5.h
  ******************************************************************************
  * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.h 733 2005-09-24 20:00:54Z svn $
+ * $Id: MessageDigest5.h 1008 2006-03-14 20:04:20Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_DIGEST5_H
@@ -85,10 +85,10 @@ private:
      * apr_uint32_t ȥ륨ǥΥХѴޤ
      *
      * @param[in] ints apr_uint32_t 
-     * @param[in] len apr_uint32_t Ĺ
+     * @param[in] length apr_uint32_t Ĺ
      * @param[out] bytes Х
      */
-    void int2byte(const apr_uint32_t *ints, apr_size_t len, apr_byte_t *bytes);
+    void int2byte(const apr_uint32_t *ints, apr_size_t length, apr_byte_t *bytes);
     void process(const apr_byte_t block[64]);
     /** ϥåͤ򻻽Фޤ */
     void create_digest();
@@ -116,11 +116,3 @@ private:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
 // End:
-
-
-
-
-
-
-
-
