@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: TemplateExecutor.h 1240 2006-07-23 17:00:41Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_EXECUTOR_H
@@ -57,7 +57,7 @@ public:
     TemplateExecutor(apr_pool_t *pool, TemplateParser::ident_map *imap,
                      TemplateVariable::variable_map *vmap,
                      ResponseWriterClass& writer);
-    void exec(TemplateParser::node *node);
+    void exec(apr_pool_t *pool, TemplateParser::node *node);
 
 private:
     typedef TemplateParser::ident_map       ident_map;
