@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 898 2005-10-24 06:11:05Z svn $
+ * $Id: UploaderConfig.h 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -80,7 +80,7 @@ public:
     const char *error_tmpl_path;
     apr_uint64_t total_file_size_limit;
     apr_size_t total_file_number_limit;
-    apr_size_t max_file_size;
+    apr_uint64_t max_file_size;
     apr_size_t per_page_item_number;
     apr_size_t remove_item_number;
 
@@ -89,7 +89,7 @@ public:
 protected:
     static const apr_uint64_t TOTAL_FILE_SIZE_LIMIT;
     static const apr_size_t TOTAL_FILE_NUMBER_LIMIT;
-    static const apr_size_t MAX_FORM_FILE_SIZE;
+    static const apr_uint64_t MAX_FORM_FILE_SIZE;
     static const apr_size_t MAX_FORM_TEXT_SIZE;
     static const apr_size_t MAX_FORM_ITEM_NUMBER;
     static const apr_size_t PER_PAGE_ITEM_NUMBER;
