@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader_apache.h 1065 2006-05-15 13:58:22Z svn $
+ * $Id: mod_uploader_apache.h 1069 2006-05-17 13:43:19Z svn $
  *****************************************************************************/
 
 #ifndef MOD_UPLOADER_APACHE_H
@@ -71,8 +71,8 @@ typedef struct ServerConfig {
     pprogress *progress_list;
 } sconfig;
 
-// Apache 2.0 ϤξϡAP_NEED_SET_MUTEX_PERMS  define ߤ롥
-#ifndef AP_SERVER_MAJORVERSION_NUMBER
+// Apache 2.0 ѤˡAP_NEED_SET_MUTEX_PERMS  define ߤ롥
+#ifndef AP_NEED_SET_MUTEX_PERMS
 #if !defined(OS2) && !defined(WIN32) && !defined(BEOS) && !defined(NETWARE)
 #define AP_NEED_SET_MUTEX_PERMS
 #endif
