@@ -27,56 +27,64 @@
  * $Id: mod_uploader.h.in 570 2005-09-02 21:21:36Z svn $
  *****************************************************************************/
 
+/**
+ * @file
+ * @brief mod_uplaoder Ѥǡ¤
+ */
+
 #ifndef MOD_UPLOADER_DATA_H
+#define MOD_UPLOADER_DATA_H
 
-#define APR_NOT_DONE_YET 0
+#undef strtoul
 
-#include "httpd.h"
-#include "http_config.h"
+#include "TemplateLexer.h"
+#include "TemplateParser.h"
+#include "PostReader.h"
 
 #include "apr_time.h"
 #include "apr_global_mutex.h"
 #include "apr_shm.h"
 
-#undef strtoul
+const apr_size_t MAX_PARAM_LENGTH       = 512;
+const apr_size_t MAX_PARAM_NUMBER       = 4;
 
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
+const char UPLOAD_COMMAND[]             = "upload";
+const char PROGRESS_COMMAND[]           = "progress";
+const char PROGRESS_DATA_COMMAND[]      = "progress_data";
+const char DOWNLOAD_COMMAND[]           = "download";
+const char REMOVE_COMMAND[]             = "remove";
+const char RSS_COMMAND[]                = "rss";
+const char THUMBNAIL_COMMAND[]          = "thumbnail";
+const char IMAGE_COMMAND[]              = "image";
 
-#include "PostReader.h"
+const char UPLOAD_LOCK_NAME[]           = "." PACKAGE_NAME ".upload_lock";
+const char PROGRESS_LOCK_NAME[]         = "." PACKAGE_NAME ".progress_lock";
+const char REVISION_NAME[]              = "." PACKAGE_NAME ".revision";
+const char POSTER_LIST_NAME[]           = "." PACKAGE_NAME ".poster_list";
+const char PROGRESS_LIST_NAME[]         = "." PACKAGE_NAME ".progress_list";
 
-extern "C" module AP_MODULE_DECLARE_DATA uploader_module;
-
-const apr_size_t MAX_ADDRESS_LENGTH         = 64;
+const apr_size_t MAX_ADDRESS_LENGTH     = 64;
 
 typedef PostReader::progress pprogress;
 
+typedef struct PageTemplate {
+    TemplateLexer::ident_map *imap;
+    TemplateParser::node *node;
+    apr_time_t mtime;
+
+    PageTemplate()
+    {
+        imap    = NULL;
+        node    = NULL;
+        mtime   = 0;
+    }
+} page_template;
+
 typedef struct Poster {
     apr_time_t time;
     char address[MAX_ADDRESS_LENGTH];
 } poster;
 
-typedef struct ServerConfig {
-    char *upload_lock_path;
-    apr_global_mutex_t *upload_lock;
-
-    char *progress_lock_path;
-    apr_global_mutex_t *progress_lock;
-
-    char *poster_list_path;
-    apr_shm_t *poster_list_shm;
-    poster *poster_list;
-
-    char *progress_list_path;
-    apr_shm_t *progress_list_shm;
-    // δñΤᡤprogress_list[0] ϼºݤˤϻѤʤ
-    // (NullObject ѥɤ)
-    pprogress *progress_list;
-} sconfig;
-
 #endif
 
 // Local Variables:
