@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 919 2005-11-22 06:43:05Z svn $
+ * $Id: Auxiliary.cpp 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #include "Auxiliary.h"
@@ -32,8 +32,9 @@
 
 #include "apr_file_info.h"
 #include "apr_strings.h"
+#define APR_WANT_STRFUNC
+#include "apr_want.h"
 
-#include <string.h>
 #include <ctype.h>
 
 static const char *MON_STR[]                = {
@@ -64,20 +65,19 @@ const char *escape_html(apr_pool_t *pool, const char* str)
     static const char GREATER_THAN[]    = "&gt;";
     static const char AMPERSAND[]       = "&amp;";
 
-    const char *plain;
     char *escaped;
     char *buffer;
     apr_size_t escaped_length;
 
     escaped_length = 0;
-    plain = str;
-    do {
+
+    for (const char *plain = str; *plain != '\0'; plain++) {
         if ((*plain == '<') || (*plain == '>')) {
             escaped_length += 3;
         } else if (*plain == '&') {
             escaped_length += 4;
         }
-    } while (*(++plain) != '\0');
+    }
 
     if (escaped_length == 0) {
         return apr_pstrdup(pool, str);
@@ -87,7 +87,7 @@ const char *escape_html(apr_pool_t *pool, const char* str)
     APR_PCALLOC(escaped, char *, pool, escaped_length + 1);
     buffer = escaped;
 
-    do {
+    for (; *str != '\0'; str++) {
         if (*str == '<') {
             memcpy(buffer, LESS_THAN, strlen(LESS_THAN));
             buffer += strlen(LESS_THAN);
@@ -100,7 +100,7 @@ const char *escape_html(apr_pool_t *pool, const char* str)
         } else {
             *buffer++ = *str;
         }
-    } while (*(++str) != '\0');
+    }
 
     return escaped;
 }
@@ -109,19 +109,17 @@ const char *rfc1738_encode(apr_pool_t *pool, const char* str)
 {
     static char hex[] = "0123456789ABCDEF";
 
-    const char *plain;
     apr_size_t not_alnum;
     char *encoded;
     char *buffer;
     unsigned char c;
 
     not_alnum = 0;
-    plain = str;
-    do {
+    for (const char *plain = str; *plain != '\0'; plain++) {
         if (!isalnum(*plain)) {
             not_alnum++;
         }
-    } while (*(++plain) != '\0');
+    }
 
     if (not_alnum == 0) {
         return apr_pstrdup(pool, str);
@@ -130,7 +128,7 @@ const char *rfc1738_encode(apr_pool_t *pool, const char* str)
     APR_PCALLOC(encoded, char *, pool, strlen(str) + (not_alnum*2) + 1);
     buffer = encoded;
 
-    do {
+    for (; *str != '\0'; str++) {
         *buffer = *str;
 
         if (!isalnum(*buffer)) {
@@ -142,7 +140,7 @@ const char *rfc1738_encode(apr_pool_t *pool, const char* str)
         } else {
             buffer++;
         }
-    } while (*(++str) != '\0');
+    }
 
     return encoded;
 }
