@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.cpp 1063 2006-05-13 03:10:51Z svn $
+ * $Id: RFC1867Parser.cpp 1241 2006-07-30 15:42:10Z svn $
  *****************************************************************************/
 
 #include "RFC1867Parser.h"
@@ -40,6 +40,7 @@
 #include "apr_want.h"
 
 #include <stdlib.h>
+#include <ctype.h>
 
 #ifdef DEBUG
 #include <iostream>
@@ -558,7 +559,7 @@ const char *RFC1867Parser<FileWriterClass, PostReaderClass>::skip(apr_pool_t *po
 
     if (is_must && !is_exist) {
         DUMP_INPUT(input_start);
-        throw apr_pstrcat(pool, pattern, " ޤ", NULL);
+        throw "ϤǤ";
     }
 
     return input_start + strlen(pattern);
