@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: TemplateExecutor.cpp 1240 2006-07-23 17:00:41Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
@@ -78,10 +78,13 @@ TemplateExecutor<ResponseWriterClass>::TemplateExecutor(apr_pool_t *pool,
 }
 
 template<class ResponseWriterClass>
-void TemplateExecutor<ResponseWriterClass>::exec(TemplateParser::node *node)
+void TemplateExecutor<ResponseWriterClass>::exec(apr_pool_t *pool,
+                                                 TemplateParser::node *node)
 {
     TRACE("exec");
 
+    vcreator_.set_pool(pool);
+
     exec_stmt(node);
 }
 
