@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: TemplateVariableCreator.cpp 1240 2006-07-23 17:00:41Z svn $
  *****************************************************************************/
 
 #include "TemplateVariableCreator.h"
@@ -79,6 +79,11 @@ TemplateVariable::scalar *TemplateVariableCreator::create_scalar(TemplateVariabl
     return scalar;
 }
 
+void TemplateVariableCreator::set_pool(apr_pool_t *pool)
+{
+    pool_ = pool;
+}
+
 apr_size_t TemplateVariableCreator::get_ident_id(TemplateVariable::ident_map *imap,
                                                  const char *name)
 {
