@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UnixThumbnailWriter.cpp 1073 2006-05-24 11:56:57Z svn $
+ * $Id: UnixThumbnailWriter.cpp 1081 2006-05-27 15:44:24Z svn $
  *****************************************************************************/
 
 #include "UnixThumbnailWriter.h"
@@ -121,6 +121,7 @@ bool UnixThumbnailWriter::create_movie_thumb_safe(apr_pool_t *pool, const char *
     static const int SUCCEED        = 0;
     static const int FAIL           = -1;
 
+    static const int NICE_VALUE     = 20;
     static const int TIMEOUT_SEC    = 120;
 
     pid_t pid;
@@ -129,7 +130,11 @@ bool UnixThumbnailWriter::create_movie_thumb_safe(apr_pool_t *pool, const char *
     switch (pid = fork()) {
     case 0: // ҥץ
         apr_pool_create(&pool, NULL);
+
+        // ffmpeg ˽Ȥк
+        nice(NICE_VALUE);
         alarm(TIMEOUT_SEC);
+
         exit(create_movie_thumb(pool, file_name) ? SUCCEED : FAIL);
     case -1: // 顼
         return false;
@@ -210,7 +215,7 @@ bool UnixThumbnailWriter::open_movie_file(apr_pool_t *pool, const char *file_nam
     AVInputFormat *format;
     AVProbeData probe_data;
     ByteIOContext io_context;
-    apr_byte_t buffer[ThumbnailWriter::BUFFER_SIZE];
+    apr_byte_t buffer[BUFFER_SIZE];
 
     if (apr_filepath_merge(&file_path, file_dir_, file_name,
                            APR_FILEPATH_NOTABOVEROOT, pool) != APR_SUCCESS) {
@@ -226,7 +231,7 @@ bool UnixThumbnailWriter::open_movie_file(apr_pool_t *pool, const char *file_nam
     probe_data.filename = file_path;
     probe_data.buf = buffer;
     probe_data.buf_size = 0;
-    probe_data.buf_size = get_buffer(&io_context, buffer, BUFFER_SIZE);
+    probe_data.buf_size = get_buffer(&io_context, buffer, sizeof(buffer));
 
     url_fseek(&io_context, 0, SEEK_SET);
 
@@ -250,8 +255,6 @@ bool UnixThumbnailWriter::open_movie_context(apr_pool_t *pool, const char *file_
                                          AVCodecContext **codec_context,
                                          AVCodec **codec, int *video_index)
 {
-    int i;
-
     av_register_all();
 
     if (!open_movie_file(pool, file_path, format_context)) {
@@ -263,7 +266,7 @@ bool UnixThumbnailWriter::open_movie_context(apr_pool_t *pool, const char *file_
     }
 
     *video_index = -1;
-    for (i = 0; i < (*format_context)->nb_streams; ++i) {
+    for (int i = 0; i < (*format_context)->nb_streams; ++i) {
         if ((*format_context)->streams[i]->codec->codec_type == CODEC_TYPE_VIDEO) {
             *video_index = i;
             break;
@@ -302,9 +305,13 @@ void UnixThumbnailWriter::read_movie_frames(AVFormatContext *format_context,
                                         apr_size_t frame_number,
                                         list<Magick::Image>& frame_list)
 {
+    static const apr_size_t MAX_INCOMPLETE_COUNT   = 1024 * 1024 / BUFFER_SIZE;
+
     AVPacket packet;
     apr_size_t movie_fps;
     int is_frame_finish;
+    apr_size_t decode_bytes;
+    apr_size_t incomplete_count;
     apr_size_t i;
     apr_size_t j;
     Magick::Geometry thumb_size(codec_context->width, codec_context->height);
@@ -317,6 +324,7 @@ void UnixThumbnailWriter::read_movie_frames(AVFormatContext *format_context,
 
     // TODO: av_seek_frame 夤ƤʲΥ롼פ롥
 
+    incomplete_count = 0;
     i = j = 0;
     while (av_read_frame(format_context, &packet) >= 0) {
         if (packet.stream_index != video_index) {
@@ -324,17 +332,33 @@ void UnixThumbnailWriter::read_movie_frames(AVFormatContext *format_context,
             continue;
         }
 
-        if (avcodec_decode_video(codec_context, frame, &is_frame_finish,
-                                 packet.data, packet.size) < 0) {
+        if ((decode_bytes = avcodec_decode_video(codec_context, frame, &is_frame_finish,
+                                                 packet.data, packet.size)) < 0) {
             av_free_packet(&packet);
 
-            throw "ưΥǥɤ˼Ԥޤ";
+            throw "ưΥǥɤ˼Ԥޤ(1)";
         }
 
-        if (!is_frame_finish || ((++i % static_cast<apr_size_t>(movie_fps*frame_sample)) != 0)) {
+        if ((is_frame_finish == 0) ||
+            ((++i % static_cast<apr_size_t>(movie_fps*frame_sample)) != 0)) {
             av_free_packet(&packet);
-            continue;
+
+            if (decode_bytes != 0) {
+                continue;
+            }
+
+            if (++incomplete_count != MAX_INCOMPLETE_COUNT) {
+                continue;
+            }
+
+            // Ԥ³ϡǥɤڤ夲롥
+            if (frame_list.size() == 0) {
+                throw "ưΥǥɤ˼Ԥޤ(2)";
+            } else {
+                return;
+            }
         }
+        incomplete_count = 0;
 
         if (img_convert(picture, FRAME_PIXEL_FORMAT,
                         reinterpret_cast<AVPicture *>(frame),
