@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 896 2005-10-23 19:31:04Z svn $
+ * $Id: UploadItem.cpp 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -56,7 +56,7 @@ const char UploadItem::TIME_KEY[]               = "time";
 
 const char UploadItem::TIME_FORMAT[]            = UITEM_TIME_FORMAT;
 const apr_size_t UploadItem::MAX_TIME_LENGTH    = UITEM_MAX_TIME_LENGTH;
-const apr_size_t UploadItem::TIME_ZONE_OFFSET   = UITEM_TIME_ZONE_OFFSET;
+const apr_int32_t UploadItem::TIME_ZONE_OFFSET  = UITEM_TIME_ZONE_OFFSET;
 
 
 /******************************************************************************
