@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: UploadItemReader.cpp 1240 2006-07-23 17:00:41Z svn $
  *****************************************************************************/
 
 #include "UploadItemReader.h"
@@ -50,15 +50,17 @@ UploadItemReader::UploadItemReader(apr_pool_t *pool, const char *file_dir)
 
 UploadItem::header *UploadItemReader::read(const char *file_name,
                                            apr_file_t **file,
-                                           bool is_buffered)
+                                           bool is_buffered,
+                                           bool is_sendfile_enabled)
 {
-    return read(pool_, file_name, file, is_buffered);
+    return read(pool_, file_name, file, is_buffered, is_sendfile_enabled);
 }
 
 UploadItem::header *UploadItemReader::read(apr_pool_t *pool,
                                            const char *file_name,
                                            apr_file_t **file,
-                                           bool is_buffered)
+                                           bool is_buffered,
+                                           bool is_sendfile_enabled)
 {
     char *file_path;
     apr_size_t size;
@@ -71,7 +73,9 @@ UploadItem::header *UploadItemReader::read(apr_pool_t *pool,
     }
 
     if (apr_file_open(file, file_path,
-                      APR_READ|APR_BINARY|APR_SENDFILE_ENABLED|(is_buffered ? APR_BUFFERED : 0),
+                      APR_READ|APR_BINARY |
+                      (is_sendfile_enabled ? (APR_SENDFILE_ENABLED|APR_XTHREAD) : 0) |
+                      (is_buffered ? APR_BUFFERED : 0),
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
         throw "åץɥե򳫤ޤǤ";
     }
