@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: UploaderConfig.cpp 1241 2006-07-30 15:42:10Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -218,10 +218,12 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
     apr_file_t *file;
     apr_mmap_t *file_map = NULL;
     apr_finfo_t info;
+    TemplateLexer::ident_map *old_imap = NULL;
+    apr_pool_t *old_tmpl_pool = NULL;
 
     if (apr_file_open(&file, template_path, APR_READ,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
-        throw apr_psprintf(pool, "Can not open page template. (%s)", template_path);
+        throw "Can not open page template.";
     }
 
     try {
@@ -234,8 +236,8 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
             throw "ƥץ졼Ȥ mmap ˼Ԥޤ";
         }
 
-        delete tmpl->imap;
-        DESTROY(*tmpl_pool);
+        old_imap = tmpl->imap;
+        old_tmpl_pool = *tmpl_pool;
 
         if (apr_pool_create(tmpl_pool, pool_) != APR_SUCCESS) {
             throw "ƥץ졼ѤΥݤ˼Ԥޤ";
@@ -252,12 +254,19 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
         apr_mmap_delete(file_map);
         apr_file_close(file);
 
+        delete old_imap;
+        DESTROY(old_tmpl_pool);
     } catch(const char *) {
         if (file_map != NULL) {
             apr_mmap_delete(file_map);
         }
         apr_file_close(file);
 
+        if (old_imap != NULL) {
+            delete old_imap;
+        }
+        DESTROY(old_tmpl_pool);
+
         throw;
     }
 }
@@ -267,8 +276,7 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *path)
     apr_finfo_t info;
 
     if (UNLIKELY(apr_stat(&info, path, APR_FINFO_MTIME, pool) != APR_SUCCESS)) {
-        throw apr_psprintf(pool, "Can not get information of file/directory. (%s)",
-                           path);
+        throw "Can not get information of file/directory.";
     }
 
     return info.mtime;
