@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ThumbnailWriter.cpp 929 2005-12-07 16:22:39Z svn $
+ * $Id: WindowsThumbnailWriter.cpp,v 1.8 2006/05/27 17:10:23 kimata Exp $
  *****************************************************************************/
 
 #pragma warning(disable:4251)
@@ -185,13 +185,12 @@ UploadItemStream *WindowsThumbnailWriter::wmv_open_movie_file(apr_pool_t *pool,
         throw "ե stat ˼Ԥޤ";
     }
 
-    return new UploadItemStream(pool, file,
-                                info.size-sizeof(UploadItem::header));
+    return new UploadItemStream(pool, file, info.size-sizeof(UploadItem::header));
 }
 
 IWMSyncReader *WindowsThumbnailWriter::wmv_open_movie(UploadItemStream *stream)
 {
-    IWMSyncReader *wmv_reader;
+    IWMSyncReader *wmv_reader = NULL;
 
     if (FAILED(WMCreateSyncReader(NULL, 0, &wmv_reader))) {
         throw "WMV ɤ߹ѥ֥Ȥ˼Ԥޤ";
@@ -323,7 +322,7 @@ void WindowsThumbnailWriter::wmv_read_frame_image(IWMSyncReader *wmv_reader,
     QWORD frame_time = 0;
     QWORD frame_duration = 0;
     DWORD frame_flag = 0;
-    BYTE *frame_buffer;
+    BYTE *frame_buffer = NULL;
 
     try {
         if (FAILED(wmv_reader->GetNextSample(stream_number, &stream_buffer, &frame_time,
@@ -462,6 +461,7 @@ PGETFRAME WindowsThumbnailWriter::avi_open_frame(PAVISTREAM stream)
     PGETFRAME frame;
 
     if ((frame = AVIStreamGetFrameOpen(stream, NULL)) == NULL) {
+        // ǤΤϡ餯ǥåꡥ
         throw "AVI ɤ߹ߤ˼Ԥޤ(5)";
     }
 
