@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: apache_handler.cpp 1023 2006-04-16 16:53:14Z svn $
+ * $Id: apache_handler.cpp 1247 2006-08-05 05:45:40Z svn $
  *****************************************************************************/
 
 #include "apache_handler.h"
@@ -43,13 +43,19 @@
 #include "Auxiliary.h"
 #include "Misc.h"
 
-#include "http_protocol.h"
+#define CORE_PRIVATE
+#include "http_core.h"
 #include "http_log.h"
 
 #define APR_WANT_STRFUNC
 #include "apr_want.h"
 
 #include <stdlib.h>
+#include <ctype.h>
+
+#ifdef DEBUG
+#include <iostream>
+#endif
 
 #define INFO(command, target)                   \
     ap_log_rerror(APLOG_MARK, APLOG_INFO, 0, r, \
@@ -137,7 +143,7 @@ static int error(request_rec *r, uconfig *config, const char *error)
 
     ApacheResponseWriter writer(r);
     ApacheTemplateExecutor texecutor(r->pool, tmpl->imap, vmap.get(), writer);
-    texecutor.exec(tmpl->node);
+    texecutor.exec(r->pool, tmpl->node);
 
     return OK;
 }
@@ -175,7 +181,7 @@ static int input_pass(request_rec *r, uconfig *config, const char *arg,
 
         ApacheResponseWriter writer(r);
         ApacheTemplateExecutor texecutor(r->pool, tmpl->imap, vmap.get(), writer);
-        texecutor.exec(tmpl->node);
+        texecutor.exec(r->pool, tmpl->node);
     } catch(const char *message) {
         ap_rputs("<div class=\"warning\">", r);
         ap_rputs(message, r);
@@ -213,7 +219,7 @@ static int view(request_rec *r, uconfig *config, const char *arg)
 
         ApacheResponseWriter writer(r);
         ApacheTemplateExecutor texecutor(r->pool, tmpl->imap, vmap.get(), writer);
-        texecutor.exec(tmpl->node);
+        texecutor.exec(r->pool, tmpl->node);
 
         config->read_unlock();
     } catch(const char *message) {
@@ -256,7 +262,7 @@ static int thumbnail(request_rec *r, uconfig *config, const char *arg)
 
         ApacheResponseWriter writer(r);
         ApacheTemplateExecutor texecutor(r->pool, tmpl->imap, vmap.get(), writer);
-        texecutor.exec(tmpl->node);
+        texecutor.exec(r->pool, tmpl->node);
 
         config->read_unlock();
     } catch(const char *message) {
@@ -402,7 +408,7 @@ static int progress(request_rec *r, uconfig *config, const char *arg)
 
         ApacheResponseWriter writer(r);
         ApacheTemplateExecutor texecutor(r->pool, tmpl->imap, vmap.get(), writer);
-        texecutor.exec(tmpl->node);
+        texecutor.exec(r->pool, tmpl->node);
     } catch(const char *message) {
         ap_rputs("<div class=\"warning\">", r);
         ap_rputs(message, r);
@@ -437,33 +443,55 @@ static int progress_data(request_rec *r, uconfig *config, const char *arg)
     return OK;
 }
 
-static apr_status_t http_sendfile(apr_file_t *file, request_rec *r,
-                                  apr_off_t offset, apr_size_t length,
-                                  apr_size_t *send_bytes)
+static int http_sendfile(apr_file_t *file, request_rec *r, apr_off_t offset,
+                         apr_size_t length,
+                         bool is_sendfile_enabled, bool is_mmap_enabled)
 {
     conn_rec *c;
     apr_bucket_brigade *bb;
     apr_bucket *b;
-    apr_status_t status;
 
     c = r->connection;
 
     bb = apr_brigade_create(r->pool, c->bucket_alloc);
 
     b = apr_bucket_file_create(file, offset, length, r->pool, c->bucket_alloc);
-    APR_BRIGADE_INSERT_TAIL(bb, b);
+#if APR_HAS_MMAP
+    if (!is_mmap_enabled) {
+        apr_bucket_file_enable_mmap(b, 0);
+    }
+#endif
 
+    APR_BRIGADE_INSERT_TAIL(bb, b);
     b = apr_bucket_eos_create(c->bucket_alloc);
     APR_BRIGADE_INSERT_TAIL(bb, b);
 
-    status = ap_pass_brigade(r->output_filters, bb);
-    if (status != APR_SUCCESS) {
-        *send_bytes = 0;
-    } else {
-        *send_bytes = length;
+    if (ap_pass_brigade(r->output_filters, bb) != APR_SUCCESS) {
+        return HTTP_INTERNAL_SERVER_ERROR;
     }
 
-    return status;
+    return OK;
+}
+
+static void get_core_option(request_rec *r,
+                            bool *is_sendfile_enabled,
+                            bool *is_mmap_enabled)
+{
+    core_dir_config *core_config;
+
+    core_config = (core_dir_config *)ap_get_module_config(r->per_dir_config,
+                                                          &core_module);
+
+    *is_sendfile_enabled = false;
+    *is_mmap_enabled = false;
+
+#if APR_HAS_SENDFILE
+    *is_sendfile_enabled = (core_config->enable_sendfile != ENABLE_SENDFILE_OFF);
+#endif
+
+#if APR_HAS_MMAP
+    *is_mmap_enabled = (core_config->enable_mmap != ENABLE_MMAP_OFF);
+#endif
 }
 
 static int download(request_rec *r, uconfig *config, const char *arg)
@@ -495,11 +523,14 @@ static int download(request_rec *r, uconfig *config, const char *arg)
         const char *file_name;
         const char *password;
         const char *open_mode;
-        apr_size_t size;
         apr_status_t status;
+        bool is_sendfile_enabled;
+        bool is_mmap_enabled;
+
+        get_core_option(r, &is_sendfile_enabled, &is_mmap_enabled);
 
         auto_ptr<UploadItemReader> reader(config->get_ureader(r->pool));
-        header = reader->read(name, &file);
+        header = reader->read(name, &file, false, is_sendfile_enabled);
 
         password = apr_table_get(get_param_table(r), UploadItem::DOWNLOAD_PASS_PARAM);
 
@@ -513,6 +544,7 @@ static int download(request_rec *r, uconfig *config, const char *arg)
         ap_update_mtime(r, header->time);
         ap_set_last_modified(r);
         ap_set_etag(r);
+        apr_table_setn(r->headers_out, "Accept-Ranges", "bytes");
 
         if ((status = ap_meets_conditions(r)) != OK) {
             return status;
@@ -532,18 +564,13 @@ static int download(request_rec *r, uconfig *config, const char *arg)
         open_mode = (r->args == NULL) ? "inline" : "attachment";
 
         // Content-Disposition
-        ap_set_content_length(r, header->file_size);
         apr_table_setn(r->headers_out, "Content-Disposition",
                        apr_psprintf(r->pool,
                                     "%s; filename=\"%s\"", open_mode, file_name));
 
-        http_sendfile(file, r, sizeof(UploadItem::header),
-                      static_cast<apr_size_t>(header->file_size), // MEMO: 4GB 
-                      &size);
-
-        apr_file_close(file);
-
-        return OK;
+        return http_sendfile(file, r, sizeof(UploadItem::header),
+                             static_cast<apr_size_t>(header->file_size), // MEMO: 4GB 
+                             is_sendfile_enabled, is_mmap_enabled);
     } catch(const char *message) {
         return error(r, config, message);
     }
@@ -599,10 +626,17 @@ int command_handler(request_rec *r, uconfig *config, const char *arg)
     const char *command;
 
     if (UNLIKELY(*arg == '\0')) {
+        if (UNLIKELY(*(r->uri + strlen(r->uri) - 1) == '/')) {
+            return error(r, config,
+                         apr_psprintf(r->pool,
+                                      "ǥ쥯ȥޤϥե%sפ¸ߤƤޤ",
+                                      r->filename));
+        }
         apr_table_set(r->headers_out, "Location", apr_pstrcat(r->pool, r->uri, "/", NULL));
         return HTTP_TEMPORARY_REDIRECT;
+    } else {
+        arg++;
     }
-    arg++;
 
     command = ap_getword(r->pool, &arg, '/');
 
