@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_func.cpp 1003 2006-03-14 13:52:47Z svn $
+ * $Id: uploader_func.cpp 1240 2006-07-23 17:00:41Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -41,7 +41,7 @@
 #include <iostream>
 #endif
 
-#ifdef _MSC_VER
+#if _MSC_VER >= 1400
 const char *safe_getenv(apr_pool_t *pool, const char *key)
 {
     static const size_t BUFFER_SIZE = 512;
