@@ -29,28 +29,14 @@ if ($args{'mode'} eq 'release') {
     my $win32_bin_link = (grep($_->text() =~ /^mod_uploader\.so-.*\.zip$/, @links))[0];
 
     while (<>) {
-        if (/\Q<!-- MARK:mod_uploader -->\E/) {
+        if (/\* `mod_uploader-\d+\.\d+\.\d+\.tgz/) {
             print << "__HTML__";
-<!-- MARK:mod_uploader -->
-    <a href="@{[$src_link->url()]}[0]">
-     @{[$src_link->text()]}[0]
-    </a>
-<!-- MARK:mod_uploader -->
+* `@{[$src_link->text()]}[0] <@{[$src_link->url()]}[0]>`_
 __HTML__
-            while (<>) {
-                last if (/\Q<!-- MARK:mod_uploader -->\E/);
-            }
-        } elsif (/\Q<!-- MARK:mod_uploader-win32-bin -->\E/) {
+        } elsif (/\* `mod_uploader\.so-\d+\.\d+\.\d+\.zip/) {
             print << "__HTML__";
-<!-- MARK:mod_uploader-win32-bin -->
-    <a href="@{[$win32_bin_link->url()]}[0]">
-     @{[$win32_bin_link->text()]}[0]
-    </a>
-<!-- MARK:mod_uploader-win32-bin -->
+* `@{[$win32_bin_link->text()]}[0] <@{[$win32_bin_link->url()]}[0]>`_
 __HTML__
-            while (<>) {
-                last if (/\Q<!-- MARK:mod_uploader-win32-bin -->\E/);
-            }
         } else {
             print;
         }
